@@ -40,6 +40,16 @@ class Settings { /* {{{ */
 	var $_enableGuestLogin = false;
 	// Allow users to reset their password
 	var $_enablePasswordForgotten = false;
+	// Minimum password strength (0 - x, 0 means no check)
+	var $_passwordStrength = 0;
+	// Password strength algorithm (simple, advanced)
+	var $_passwordStrengthAlgorithm = 'advanced';
+	// Number of days when a password expires and must be reset
+	var $_passwordExpiration = 10;
+	// Number of different passwords before a password can be reused
+	var $_passwordHistory = 10;
+	// Number of failed logins before account is disabled
+	var $_loginFailure = 0;
 	// Restricted access: only allow users to log in if they have an entry in
 	// the local database (irrespective of successful authentication with LDAP).
 	var $_restricted = true;
@@ -89,6 +99,14 @@ class Settings { /* {{{ */
 	var $_enableUsersView = true;
 	// enable/disable listing administrator as reviewer/approver
 	var $_enableAdminRevApp = false;
+	// enable/disable default notification for owner
+	var $_enableOwnerNotification = false;
+	// enable/disable deleting of versions for regular users
+	var $_enableVersionDeletion = false;
+	// enable/disable to overwrite the status of a version for regular users
+	var $_enableVersionModification = false;
+	// enable/disable notification when added as a reviewer/approver
+	var $_enableNotificationAppRev = true;
 	// the name of the versioning info file created by the backup tool
 	var $_versioningFileName = "versioning_info.txt";
 	// enable/disable log system
@@ -113,6 +131,9 @@ class Settings { /* {{{ */
 	var $_expandFolderTree = 1;
 	// enable/disable editing of users own profile
 	var $_disableSelfEdit = false;
+	// Sort order of users in lists('fullname' or '' (login))
+	var $_sortUsersInList = '';
+	// enable/disable lucene fulltext search
 	// if enabled admin can login only by specified IP addres
 	var $_adminIP = "";
 	// Max Execution Time
@@ -141,7 +162,7 @@ class Settings { /* {{{ */
 	var $_ldapBaseDN = "";
 	var $_ldapAccountDomainName = "";
 	var $_ldapType = 1; // 0 = ldap; 1 = AD
-
+	var $_converters = array(); // list of commands used to convert files to text for Indexer
 
 	/**
 	 * Constructor
@@ -257,6 +278,7 @@ class Settings { /* {{{ */
 		$this->_enableFolderTree = Settings::boolVal($tab["enableFolderTree"]);
 		$this->_enableFullSearch = Settings::boolVal($tab["enableFullSearch"]);
 		$this->_stopWordsFile = strval($tab["stopWordsFile"]);
+		$this->_sortUsersInList = strval($tab["sortUsersInList"]);
 		$this->_expandFolderTree = intval($tab["expandFolderTree"]);
 
 		// XML Path: /configuration/site/calendar
@@ -284,6 +306,11 @@ class Settings { /* {{{ */
 		$tab = $node[0]->attributes();
 		$this->_enableGuestLogin = Settings::boolVal($tab["enableGuestLogin"]);
 		$this->_enablePasswordForgotten = Settings::boolVal($tab["enablePasswordForgotten"]);
+		$this->_passwordStrength = intval($tab["passwordStrength"]);
+		$this->_passwordStrengthAlgorithm = strval($tab["passwordStrengthAlgorithm"]);
+		$this->_passwordExpiration = intval($tab["passwordExpiration"]);
+		$this->_passwordHistory = intval($tab["passwordHistory"]);
+		$this->_loginFailure = intval($tab["loginFailure"]);
 		$this->_encryptionKey = strval($tab["encryptionKey"]);
 		$this->_restricted = Settings::boolVal($tab["restricted"]);
 		$this->_enableUserImage = Settings::boolVal($tab["enableUserImage"]);
@@ -375,6 +402,16 @@ class Settings { /* {{{ */
 		$tab = $node[0]->attributes();
 		$this->_enableAdminRevApp = Settings::boolval($tab["enableAdminRevApp"]);
 		$this->_versioningFileName = strval($tab["versioningFileName"]);
+		$this->_enableVersionDeletion = Settings::boolval($tab["enableVersionDeletion"]);
+		$this->_enableVersionModification = Settings::boolval($tab["enableVersionModification"]);
+
+		// XML Path: /configuration/advanced/notification
+		$node = $xml->xpath('/configuration/advanced/notification');
+		if($node) {
+			$tab = $node[0]->attributes();
+			$this->_enableNotificationAppRev = Settings::boolval($tab["enableNotificationAppRev"]);
+			$this->_enableOwnerNotification = Settings::boolval($tab["enableOwnerNotification"]);
+		}
 
 		// XML Path: /configuration/advanced/server
 		$node = $xml->xpath('/configuration/advanced/server');
@@ -388,6 +425,14 @@ class Settings { /* {{{ */
 			$this->_maxExecutionTime = intval($tab["maxExecutionTime"]);
 		else
 			$this->_maxExecutionTime = ini_get("max_execution_time");
+
+		// XML Path: /configuration/system/advanced/converters
+		$converters = $xml->xpath('/configuration/advanced/converters/converter');
+		$this->_converters = array();
+		foreach($converters as $converter) {
+			$tab = $converter->attributes();
+			$this->_converters[trim(strval($tab['mimeType']))] = trim(strval($converter));
+		}
 	} /* }}} */
 
 	 /**
@@ -472,6 +517,7 @@ class Settings { /* {{{ */
     $this->setXMLAttributValue($node, "enableFullSearch", $this->_enableFullSearch);
     $this->setXMLAttributValue($node, "expandFolderTree", $this->_expandFolderTree);
     $this->setXMLAttributValue($node, "stopWordsFile", $this->_stopWordsFile);
+    $this->setXMLAttributValue($node, "sortUsersInList", $this->_sortUsersInList);
 
     // XML Path: /configuration/site/calendar
     $node = $this->getXMLNode($xml, '/configuration/site', 'calendar');
@@ -496,6 +542,11 @@ class Settings { /* {{{ */
     $node = $this->getXMLNode($xml, '/configuration/system', 'authentication');
     $this->setXMLAttributValue($node, "enableGuestLogin", $this->_enableGuestLogin);
     $this->setXMLAttributValue($node, "enablePasswordForgotten", $this->_enablePasswordForgotten);
+    $this->setXMLAttributValue($node, "passwordStrength", $this->_passwordStrength);
+    $this->setXMLAttributValue($node, "passwordStrengthAlgorithm", $this->_passwordStrengthAlgorithm);
+    $this->setXMLAttributValue($node, "passwordExpiration", $this->_passwordExpiration);
+    $this->setXMLAttributValue($node, "passwordHistory", $this->_passwordHistory);
+    $this->setXMLAttributValue($node, "loginFailure", $this->_loginFailure);
     $this->setXMLAttributValue($node, "encryptionKey", $this->_encryptionKey);
     $this->setXMLAttributValue($node, "restricted", $this->_restricted);
     $this->setXMLAttributValue($node, "enableUserImage", $this->_enableUserImage);
@@ -581,6 +632,13 @@ class Settings { /* {{{ */
     $node = $this->getXMLNode($xml, '/configuration/advanced', 'edition');
     $this->setXMLAttributValue($node, "enableAdminRevApp", $this->_enableAdminRevApp);
     $this->setXMLAttributValue($node, "versioningFileName", $this->_versioningFileName);
+    $this->setXMLAttributValue($node, "enableVersionDeletion", $this->_enableVersionDeletion);
+    $this->setXMLAttributValue($node, "enableVersionModification", $this->_enableVersionModification);
+
+    // XML Path: /configuration/advanced/notification
+    $node = $this->getXMLNode($xml, '/configuration/advanced', 'notification');
+    $this->setXMLAttributValue($node, "enableNotificationAppRev", $this->_enableNotificationAppRev);
+    $this->setXMLAttributValue($node, "enableOwnerNotification", $this->_enableOwnerNotification);
 
     // XML Path: /configuration/advanced/server
     $node = $this->getXMLNode($xml, '/configuration/advanced', 'server');
@@ -591,6 +649,31 @@ class Settings { /* {{{ */
     $this->setXMLAttributValue($node, "updateNotifyTime", $this->_updateNotifyTime);
     $this->setXMLAttributValue($node, "maxExecutionTime", $this->_maxExecutionTime);
 
+    // XML Path: /configuration/advanced/converters
+    foreach($this->_converters as $mimeType => $cmd)
+    {
+      // search XML node
+      $node = $xml->xpath('/configuration/advanced/converters/converter[@mimeType="'. $mimeType .'"]');
+
+      if (isset($node))
+      {
+        if (count($node)>0)
+        {
+          $node = $node[0];
+        }
+        else
+        {
+          $nodeParent = $xml->xpath('/configuration/advanced/converters');
+          $node = $nodeParent[0]->addChild("converters");
+        }
+
+				$node[0] = $cmd;
+        $this->setXMLAttributValue($node, 'mimeType', $mimeType);
+
+      } // isset($node)
+
+    } // foreach
+
 
     // Save
     return $xml->asXML($configFilePath);
@@ -903,9 +986,8 @@ class Settings { /* {{{ */
 							*/
 							}
 						}
+						$connTmp->Disconnect();
 					}
-
-					$connTmp->Disconnect();
 				}
 			} catch(Exception $e) {
 				$result["dbDatabase"] = array(
