@@ -598,6 +598,24 @@ class UI {
 		print "&nbsp;&nbsp;<input type=\"Button\" value=\"".getMLText("category")."...\" onclick=\"chooseCategory".$formName."();\">";
 	} /* }}} */
 
+	function printAttributeEditField($attrdef, $objvalue, $fieldname='attributes') { /* {{{ */
+		if($valueset = $attrdef->getValueSetAsArray()) {
+			echo "<select name=\"".$fieldname."[".$attrdef->getId()."]\">";
+			if($attrdef->getMinValues() < 1) {
+				echo "<option value=\"\"></option>";
+			}
+			foreach($valueset as $value) {
+				echo "<option value=\"".htmlspecialchars($value)."\"";
+				if($value == $objvalue)
+					echo " selected";
+				echo ">".htmlspecialchars($value)."</option>";
+			}
+			echo "</select>";
+		} else {
+			echo "<input type=\"text\" name=\"".$fieldname."[".$attrdef->getId()."]\" value=\"".htmlspecialchars($objvalue)."\" />";
+		}
+	} /* }}} */
+
 	function getImgPath($img) { /* {{{ */
 		global $theme;
 
@@ -784,7 +802,7 @@ archive="jl_core_z.jar"
 width="715"
 height="400"
 mayscript>
-  <param name="uc_uploadUrl" value="<?php echo $uploadurl ?>"/>
+  <param name="uc_uploadUrl" value="<?php echo $uploadurl."?folderid=".$attributes['folderid']; unset($attributes['folderid']); ?>"/>
   <param name="ac_fireAppletInitialized" value="true"/>
   <param name="ac_fireUploaderSelectionChanged" value="true"/>
   <param name="ac_fireUploaderFileStatusChanged" value="true"/>
@@ -806,7 +824,7 @@ mayscript>
     /**
      * applet initialized notification
      */
-    function appletInitialized(  ) {
+    function uploaderInitialized(  ) {
         var uploader = document.jumpLoaderApplet.getUploader();
         var attrSet = uploader.getAttributeSet();
         var attr;
@@ -838,7 +856,7 @@ mayscript>
         traceEvent( "uploaderFileStatusChanged, index=" + file.getIndex() + ", status=" + file.getStatus() + ", content=" + file.getResponseContent() );
         if( file.isFinished() ) { 
             var serverFileName = file.getId() + "." + file.getName(); 
-            var linkHtml = "<a href='/uploaded/" + serverFileName + "'>" + serverFileName + "</a> " + file.getLength() + " bytes"; 
+            var linkHtml = serverFileName + " - " + file.getLength() + " bytes"; 
             var container = document.getElementById( "fileLinks"); 
             container.innerHTML += linkHtml + "<br />"; 
         } 
