@@ -18,9 +18,6 @@
 //    along with this program; if not, write to the Free Software
 //    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-if(isset($settings->_ADOdbPath))
-	ini_set('include_path', $settings->_ADOdbPath. PATH_SEPARATOR .ini_get('include_path'));
-
 if(!empty($settings->_coreDir))
 	require_once($settings->_coreDir.'/Core.php');
 else
