@@ -274,10 +274,66 @@ function _add_log_line($msg="") { /* {{{ */
 function showtree() { /* {{{ */
 	global $settings;
 	
-	if (isset($_GET["showtree"])) return $_GET["showtree"];
+	if (isset($_GET["showtree"])) return intval($_GET["showtree"]);
 	else if ($settings->_enableFolderTree==0) return 0;
 	
 	return 1;
 } /* }}} */
 
+/**
+ * Create a unique key which is used for form validation to prevent
+ * CSRF attacks. The key is added to a any form that has to be secured
+ * as a hidden field. Once the form is submitted the key is compared
+ * to the current key in the session and the request is only executed
+ * if both are equal. The key is derived from the session id, a configurable
+ * encryption key and form identifierer.
+ *
+ * @param string $formid individual form identifier
+ * @return string session key
+ */
+function createFormKey($formid='') { /* {{{ */
+	global $settings, $session;
+
+	if($id = $session->getId()) {
+		return md5($id.$settings->_encryptionKey.$formid);
+	} else {
+		return false;
+	}
+} /* }}} */
+
+/**
+ * Create a hidden field with the name 'formtoken' and set its value
+ * to the key returned by createFormKey()
+ *
+ * @param string $formid individual form identifier
+ * @return string input field for html formular
+ */
+function createHiddenFieldWithKey($formid='') { /* {{{ */
+	return '<input type="hidden" name="formtoken" value="'.createFormKey($formid).'" />';	
+} /* }}} */
+
+/**
+ * Check if the form key in the POST or GET request variable 'formtoken'
+ * has the value of key returned by createFormKey(). Request to modify
+ * data in the DMS should always use POST because it is harder to run
+ * CSRF attacks using POST than GET.
+ *
+ * @param string $formid individual form identifier
+ * @param string $method defines if the form data is pass via GET or
+ * POST (default)
+ * @return boolean true if key matches otherwise false
+ */
+function checkFormKey($formid='', $method='POST') { /* {{{ */
+	switch($method) {
+		case 'GET':
+			if(isset($_GET['formtoken']) && $_GET['formtoken'] == createFormKey($formid))
+				return true;
+			break;
+		default:
+			if(isset($_POST['formtoken']) && $_POST['formtoken'] == createFormKey($formid))
+				return true;
+	}
+	
+	return false;
+} /* }}} */
 ?>
