@@ -14,6 +14,37 @@ CREATE TABLE `tblACLs` (
 
 -- --------------------------------------------------------
 
+-- 
+-- Table structure for table `tblCategory`
+-- 
+
+CREATE TABLE `tblCategory` (
+  `id` int(11) NOT NULL auto_increment,
+  `name` text NOT NULL,
+  PRIMARY KEY  (`id`)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8;
+
+-- --------------------------------------------------------
+
+-- 
+-- Table structure for table `tblAttributeDefinitions`
+-- 
+
+CREATE TABLE `tblAttributeDefinitions` (
+  `id` int(11) NOT NULL auto_increment,
+  `name` varchar(100) default NULL,
+  `objtype` tinyint(4) NOT NULL default '0',
+  `type` tinyint(4) NOT NULL default '0',
+  `multiple` tinyint(4) NOT NULL default '0',
+  `minvalues` int(11) NOT NULL default '0',
+  `maxvalues` int(11) NOT NULL default '0',
+  `valueset` text default NULL,
+	UNIQUE(`name`),
+  PRIMARY KEY (`id`)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8;
+
+-- --------------------------------------------------------
+
 -- 
 -- Table structure for table `tblUsers`
 -- 
@@ -29,7 +60,11 @@ CREATE TABLE `tblUsers` (
   `comment` text NOT NULL,
   `role` smallint(1) NOT NULL default '0',
   `hidden` smallint(1) NOT NULL default '0',
-  PRIMARY KEY  (`id`)
+  `pwdExpiration` datetime NOT NULL default '0000-00-00 00:00:00',
+  `loginfailures` tinyint(4) NOT NULL default '0',
+  `disabled` smallint(1) NOT NULL default '0',
+  PRIMARY KEY (`id`),
+  UNIQUE (`login`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
 -- --------------------------------------------------------
@@ -43,7 +78,23 @@ CREATE TABLE `tblUserPasswordRequest` (
   `userID` int(11) NOT NULL default '0',
   `hash` varchar(50) default NULL,
   `date` datetime NOT NULL default '0000-00-00 00:00:00',
-  PRIMARY KEY  (`id`)
+  PRIMARY KEY  (`id`),
+  CONSTRAINT `tblUserPasswordRequest_user` FOREIGN KEY (`userID`) REFERENCES `tblUsers` (`id`) ON DELETE CASCADE
+) ENGINE=InnoDB DEFAULT CHARSET=utf8;
+
+-- --------------------------------------------------------
+
+-- 
+-- Table structure for table `tblUserPasswordHistory`
+-- 
+
+CREATE TABLE `tblUserPasswordHistory` (
+  `id` int(11) NOT NULL auto_increment,
+  `userID` int(11) NOT NULL default '0',
+  `pwd` varchar(50) default NULL,
+  `date` datetime NOT NULL default '0000-00-00 00:00:00',
+  PRIMARY KEY  (`id`),
+  CONSTRAINT `tblUserPasswordHistory_user` FOREIGN KEY (`userID`) REFERENCES `tblUsers` (`id`) ON DELETE CASCADE
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
 -- --------------------------------------------------------
@@ -58,7 +109,7 @@ CREATE TABLE `tblUserImages` (
   `image` blob NOT NULL,
   `mimeType` varchar(10) NOT NULL default '',
   PRIMARY KEY  (`id`),
-	CONSTRAINT `tblUserImages_user` FOREIGN KEY (`userID`) REFERENCES `tblUsers` (`id`) ON DELETE CASCADE
+  CONSTRAINT `tblUserImages_user` FOREIGN KEY (`userID`) REFERENCES `tblUsers` (`id`) ON DELETE CASCADE
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
 -- --------------------------------------------------------
@@ -80,7 +131,24 @@ CREATE TABLE `tblFolders` (
   `sequence` double NOT NULL default '0',
   PRIMARY KEY  (`id`),
   KEY `parent` (`parent`),
-	CONSTRAINT `tblFolders_owner` FOREIGN KEY (`owner`) REFERENCES `tblUsers` (`id`) ON DELETE CASCADE
+  CONSTRAINT `tblFolders_owner` FOREIGN KEY (`owner`) REFERENCES `tblUsers` (`id`)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8;
+
+-- --------------------------------------------------------
+
+-- 
+-- Table structure for table `tblFolderAttributes`
+-- 
+
+CREATE TABLE `tblFolderAttributes` (
+  `id` int(11) NOT NULL auto_increment,
+  `folder` int(11) default NULL,
+  `attrdef` int(11) default NULL,
+  `value` text default NULL,
+  PRIMARY KEY  (`id`),
+	UNIQUE (folder, attrdef),
+  CONSTRAINT `tblFolderAttributes_folder` FOREIGN KEY (`folder`) REFERENCES `tblFolders` (`id`) ON DELETE CASCADE,
+  CONSTRAINT `tblFolderAttributes_attrdef` FOREIGN KEY (`attrdef`) REFERENCES `tblAttributeDefinitions` (`id`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
 -- --------------------------------------------------------
@@ -104,8 +172,25 @@ CREATE TABLE `tblDocuments` (
   `keywords` text NOT NULL,
   `sequence` double NOT NULL default '0',
   PRIMARY KEY  (`id`),
-	CONSTRAINT `tblDocuments_folder` FOREIGN KEY (`folder`) REFERENCES `tblFolders` (`id`) ON DELETE CASCADE,
-	CONSTRAINT `tblDocuments_owner` FOREIGN KEY (`owner`) REFERENCES `tblUsers` (`id`) ON DELETE CASCADE
+  CONSTRAINT `tblDocuments_folder` FOREIGN KEY (`folder`) REFERENCES `tblFolders` (`id`),
+  CONSTRAINT `tblDocuments_owner` FOREIGN KEY (`owner`) REFERENCES `tblUsers` (`id`)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8;
+
+-- --------------------------------------------------------
+
+-- 
+-- Table structure for table `tblDocumentAttributes`
+-- 
+
+CREATE TABLE `tblDocumentAttributes` (
+  `id` int(11) NOT NULL auto_increment,
+  `document` int(11) default NULL,
+  `attrdef` int(11) default NULL,
+  `value` text default NULL,
+  PRIMARY KEY  (`id`),
+	UNIQUE (document, attrdef),
+  CONSTRAINT `tblDocumentAttributes_document` FOREIGN KEY (`document`) REFERENCES `tblDocuments` (`id`) ON DELETE CASCADE,
+  CONSTRAINT `tblDocumentAttributes_attrdef` FOREIGN KEY (`attrdef`) REFERENCES `tblAttributeDefinitions` (`id`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
 -- --------------------------------------------------------
@@ -122,7 +207,7 @@ CREATE TABLE `tblDocumentApprovers` (
   `required` int(11) NOT NULL default '0',
   PRIMARY KEY  (`approveID`),
   UNIQUE KEY `documentID` (`documentID`,`version`,`type`,`required`),
-	CONSTRAINT `tblDocumentApprovers_document` FOREIGN KEY (`documentID`) REFERENCES `tblDocuments` (`id`) ON DELETE CASCADE
+  CONSTRAINT `tblDocumentApprovers_document` FOREIGN KEY (`documentID`) REFERENCES `tblDocuments` (`id`) ON DELETE CASCADE
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
 -- --------------------------------------------------------
@@ -139,8 +224,8 @@ CREATE TABLE `tblDocumentApproveLog` (
   `date` datetime NOT NULL default '0000-00-00 00:00:00',
   `userID` int(11) NOT NULL default '0',
   PRIMARY KEY  (`approveLogID`),
-	CONSTRAINT `tblDocumentApproveLog_approve` FOREIGN KEY (`approveID`) REFERENCES `tblDocumentApprovers` (`approveID`) ON DELETE CASCADE,
-	CONSTRAINT `tblDocumentApproveLog_user` FOREIGN KEY (`userID`) REFERENCES `tblUsers` (`id`) ON DELETE CASCADE
+  CONSTRAINT `tblDocumentApproveLog_approve` FOREIGN KEY (`approveID`) REFERENCES `tblDocumentApprovers` (`approveID`) ON DELETE CASCADE,
+  CONSTRAINT `tblDocumentApproveLog_user` FOREIGN KEY (`userID`) REFERENCES `tblUsers` (`id`) ON DELETE CASCADE
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
 -- --------------------------------------------------------
@@ -150,6 +235,7 @@ CREATE TABLE `tblDocumentApproveLog` (
 -- 
 
 CREATE TABLE `tblDocumentContent` (
+  `id` int(11) NOT NULL auto_increment,
   `document` int(11) NOT NULL default '0',
   `version` smallint(5) unsigned NOT NULL,
   `comment` text,
@@ -159,8 +245,26 @@ CREATE TABLE `tblDocumentContent` (
   `orgFileName` varchar(150) NOT NULL default '',
   `fileType` varchar(10) NOT NULL default '',
   `mimeType` varchar(100) NOT NULL default '',
+  PRIMARY KEY  (`id`),
   UNIQUE (`document`, `version`),
-	CONSTRAINT `tblDocumentDocument_document` FOREIGN KEY (`document`) REFERENCES `tblDocuments` (`id`) ON DELETE CASCADE
+  CONSTRAINT `tblDocumentContent_document` FOREIGN KEY (`document`) REFERENCES `tblDocuments` (`id`)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8;
+
+-- --------------------------------------------------------
+
+-- 
+-- Table structure for table `tblDocumentContentAttributes`
+-- 
+
+CREATE TABLE `tblDocumentContentAttributes` (
+  `id` int(11) NOT NULL auto_increment,
+  `content` int(11) default NULL,
+  `attrdef` int(11) default NULL,
+  `value` text default NULL,
+  PRIMARY KEY  (`id`),
+	UNIQUE (content, attrdef),
+  CONSTRAINT `tblDocumentContentAttributes_document` FOREIGN KEY (`content`) REFERENCES `tblDocumentContent` (`id`) ON DELETE CASCADE,
+  CONSTRAINT `tblDocumentContentAttributes_attrdef` FOREIGN KEY (`attrdef`) REFERENCES `tblAttributeDefinitions` (`id`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
 -- --------------------------------------------------------
@@ -176,8 +280,8 @@ CREATE TABLE `tblDocumentLinks` (
   `userID` int(11) NOT NULL default '0',
   `public` tinyint(1) NOT NULL default '0',
   PRIMARY KEY  (`id`),
-	CONSTRAINT `tblDocumentLinks_document` FOREIGN KEY (`document`) REFERENCES `tblDocuments` (`id`) ON DELETE CASCADE,
-	CONSTRAINT `tblDocumentLinks_user` FOREIGN KEY (`userID`) REFERENCES `tblUsers` (`id`) ON DELETE CASCADE
+  CONSTRAINT `tblDocumentLinks_document` FOREIGN KEY (`document`) REFERENCES `tblDocuments` (`id`) ON DELETE CASCADE,
+  CONSTRAINT `tblDocumentLinks_user` FOREIGN KEY (`userID`) REFERENCES `tblUsers` (`id`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
 -- --------------------------------------------------------
@@ -198,8 +302,8 @@ CREATE TABLE `tblDocumentFiles` (
   `fileType` varchar(10) NOT NULL default '',
   `mimeType` varchar(100) NOT NULL default '',  
   PRIMARY KEY  (`id`),
-	CONSTRAINT `tblDocumentFiles_document` FOREIGN KEY (`document`) REFERENCES `tblDocuments` (`id`) ON DELETE CASCADE,
-	CONSTRAINT `tblDocumentFiles_user` FOREIGN KEY (`userID`) REFERENCES `tblUsers` (`id`) ON DELETE CASCADE
+  CONSTRAINT `tblDocumentFiles_document` FOREIGN KEY (`document`) REFERENCES `tblDocuments` (`id`) ON DELETE CASCADE,
+  CONSTRAINT `tblDocumentFiles_user` FOREIGN KEY (`userID`) REFERENCES `tblUsers` (`id`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
 
@@ -214,25 +318,8 @@ CREATE TABLE `tblDocumentLocks` (
   `document` int(11) NOT NULL default '0',
   `userID` int(11) NOT NULL default '0',
   PRIMARY KEY  (`document`),
-	CONSTRAINT `tblDocumentLocks_document` FOREIGN KEY (`document`) REFERENCES `tblDocuments` (`id`) ON DELETE CASCADE,
-	CONSTRAINT `tblDocumentLocks_user` FOREIGN KEY (`userID`) REFERENCES `tblUsers` (`id`) ON DELETE CASCADE
-) ENGINE=InnoDB DEFAULT CHARSET=utf8;
-
--- --------------------------------------------------------
-
--- 
--- Table structure for table `tblDocumentReviewLog`
--- 
-
-CREATE TABLE `tblDocumentReviewLog` (
-  `reviewLogID` int(11) NOT NULL auto_increment,
-  `reviewID` int(11) NOT NULL default '0',
-  `status` tinyint(4) NOT NULL default '0',
-  `comment` text NOT NULL,
-  `date` datetime NOT NULL default '0000-00-00 00:00:00',
-  `userID` int(11) NOT NULL default '0',
-  PRIMARY KEY  (`reviewLogID`),
-	CONSTRAINT `tblDocumentReviewLog_user` FOREIGN KEY (`userID`) REFERENCES `tblUsers` (`id`) ON DELETE CASCADE
+  CONSTRAINT `tblDocumentLocks_document` FOREIGN KEY (`document`) REFERENCES `tblDocuments` (`id`) ON DELETE CASCADE,
+  CONSTRAINT `tblDocumentLocks_user` FOREIGN KEY (`userID`) REFERENCES `tblUsers` (`id`) ON DELETE CASCADE
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
 -- --------------------------------------------------------
@@ -249,7 +336,25 @@ CREATE TABLE `tblDocumentReviewers` (
   `required` int(11) NOT NULL default '0',
   PRIMARY KEY  (`reviewID`),
   UNIQUE KEY `documentID` (`documentID`,`version`,`type`,`required`),
-	CONSTRAINT `tblDocumentReviewers_document` FOREIGN KEY (`documentID`) REFERENCES `tblDocuments` (`id`) ON DELETE CASCADE
+  CONSTRAINT `tblDocumentReviewers_document` FOREIGN KEY (`documentID`) REFERENCES `tblDocuments` (`id`) ON DELETE CASCADE
+) ENGINE=InnoDB DEFAULT CHARSET=utf8;
+
+-- --------------------------------------------------------
+
+-- 
+-- Table structure for table `tblDocumentReviewLog`
+-- 
+
+CREATE TABLE `tblDocumentReviewLog` (
+  `reviewLogID` int(11) NOT NULL auto_increment,
+  `reviewID` int(11) NOT NULL default '0',
+  `status` tinyint(4) NOT NULL default '0',
+  `comment` text NOT NULL,
+  `date` datetime NOT NULL default '0000-00-00 00:00:00',
+  `userID` int(11) NOT NULL default '0',
+  PRIMARY KEY  (`reviewLogID`),
+  CONSTRAINT `tblDocumentReviewLog_review` FOREIGN KEY (`reviewID`) REFERENCES `tblDocumentReviewers` (`reviewID`) ON DELETE CASCADE,
+  CONSTRAINT `tblDocumentReviewLog_user` FOREIGN KEY (`userID`) REFERENCES `tblUsers` (`id`) ON DELETE CASCADE
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
 -- --------------------------------------------------------
@@ -264,7 +369,7 @@ CREATE TABLE `tblDocumentStatus` (
   `version` smallint(5) unsigned NOT NULL default '0',
   PRIMARY KEY  (`statusID`),
   UNIQUE KEY `documentID` (`documentID`,`version`),
-	CONSTRAINT `tblDocumentStatus_document` FOREIGN KEY (`documentID`) REFERENCES `tblDocuments` (`id`) ON DELETE CASCADE
+  CONSTRAINT `tblDocumentStatus_document` FOREIGN KEY (`documentID`) REFERENCES `tblDocuments` (`id`) ON DELETE CASCADE
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
 -- --------------------------------------------------------
@@ -282,21 +387,8 @@ CREATE TABLE `tblDocumentStatusLog` (
   `userID` int(11) NOT NULL default '0',
   PRIMARY KEY  (`statusLogID`),
   KEY `statusID` (`statusID`),
-	CONSTRAINT `tblDocumentStatusLog_status` FOREIGN KEY (`statusID`) REFERENCES `tblDocumentStatus` (`statusID`) ON DELETE CASCADE,
-	CONSTRAINT `tblDocumentStatusLog_user` FOREIGN KEY (`userID`) REFERENCES `tblUsers` (`id`) ON DELETE CASCADE
-) ENGINE=InnoDB DEFAULT CHARSET=utf8;
-
--- --------------------------------------------------------
-
--- 
--- Table structure for table `tblGroupMembers`
--- 
-
-CREATE TABLE `tblGroupMembers` (
-  `groupID` int(11) NOT NULL default '0',
-  `userID` int(11) NOT NULL default '0',
-  `manager` smallint(1) NOT NULL default '0',
-  PRIMARY KEY  (`groupID`,`userID`)
+  CONSTRAINT `tblDocumentStatusLog_status` FOREIGN KEY (`statusID`) REFERENCES `tblDocumentStatus` (`statusID`) ON DELETE CASCADE,
+  CONSTRAINT `tblDocumentStatusLog_user` FOREIGN KEY (`userID`) REFERENCES `tblUsers` (`id`) ON DELETE CASCADE
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
 -- --------------------------------------------------------
@@ -314,6 +406,21 @@ CREATE TABLE `tblGroups` (
 
 -- --------------------------------------------------------
 
+-- 
+-- Table structure for table `tblGroupMembers`
+-- 
+
+CREATE TABLE `tblGroupMembers` (
+  `groupID` int(11) NOT NULL default '0',
+  `userID` int(11) NOT NULL default '0',
+  `manager` smallint(1) NOT NULL default '0',
+  UNIQUE (`groupID`,`userID`),
+	CONSTRAINT `tblGroupMembers_user` FOREIGN KEY (`userID`) REFERENCES `tblUsers` (`id`) ON DELETE CASCADE,
+	CONSTRAINT `tblGroupMembers_group` FOREIGN KEY (`groupID`) REFERENCES `tblGroups` (`id`) ON DELETE CASCADE
+) ENGINE=InnoDB DEFAULT CHARSET=utf8;
+
+-- --------------------------------------------------------
+
 -- 
 -- Table structure for table `tblKeywordCategories`
 -- 
@@ -336,19 +443,7 @@ CREATE TABLE `tblKeywords` (
   `category` int(11) NOT NULL default '0',
   `keywords` text NOT NULL,
   PRIMARY KEY  (`id`),
-	CONSTRAINT `tblKeywords_category` FOREIGN KEY (`category`) REFERENCES `tblKeywordCategories` (`id`) ON DELETE CASCADE
-) ENGINE=InnoDB DEFAULT CHARSET=utf8;
-
--- --------------------------------------------------------
-
--- 
--- Table structure for table `tblCategory`
--- 
-
-CREATE TABLE `tblCategory` (
-  `id` int(11) NOT NULL auto_increment,
-  `name` text NOT NULL,
-  PRIMARY KEY  (`id`)
+  CONSTRAINT `tblKeywords_category` FOREIGN KEY (`category`) REFERENCES `tblKeywordCategories` (`id`) ON DELETE CASCADE
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
 -- --------------------------------------------------------
@@ -359,7 +454,9 @@ CREATE TABLE `tblCategory` (
 
 CREATE TABLE `tblDocumentCategory` (
   `categoryID` int(11) NOT NULL default 0,
-  `documentID` int(11) NOT NULL default 0
+  `documentID` int(11) NOT NULL default 0,
+  CONSTRAINT `tblDocumentCategory_category` FOREIGN KEY (`categoryID`) REFERENCES `tblCategory` (`id`) ON DELETE CASCADE,
+  CONSTRAINT `tblDocumentCategory_document` FOREIGN KEY (`documentID`) REFERENCES `tblDocuments` (`id`) ON DELETE CASCADE
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
 -- --------------------------------------------------------
@@ -389,7 +486,7 @@ CREATE TABLE `tblSessions` (
   `theme` varchar(30) NOT NULL default '',
   `language` varchar(30) NOT NULL default '',
   PRIMARY KEY  (`id`),
-	CONSTRAINT `tblSessions_user` FOREIGN KEY (`userID`) REFERENCES `tblUsers` (`id`) ON DELETE CASCADE
+  CONSTRAINT `tblSessions_user` FOREIGN KEY (`userID`) REFERENCES `tblUsers` (`id`) ON DELETE CASCADE
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
 -- --------------------------------------------------------
@@ -471,8 +568,8 @@ CREATE TABLE `tblVersion` (
 -- Initial content for database
 --
 
-INSERT INTO tblUsers VALUES (1, 'admin', '21232f297a57a5a743894a0e4a801fc3', 'Administrator', 'address@server.com', '', '', '', 1, 0);
-INSERT INTO tblUsers VALUES (2, 'guest', NULL, 'Guest User', NULL, '', '', '', 2, 0);
+INSERT INTO tblUsers VALUES (1, 'admin', '21232f297a57a5a743894a0e4a801fc3', 'Administrator', 'address@server.com', '', '', '', 1, 0, '', 0, 0);
+INSERT INTO tblUsers VALUES (2, 'guest', NULL, 'Guest User', NULL, '', '', '', 2, 0, '', 0, 0);
 INSERT INTO tblFolders VALUES (1, 'DMS', 0, '', 'DMS root', UNIX_TIMESTAMP(), 1, 0, 2, 0);
-INSERT INTO tblVersion VALUES (NOW(), 3, 3, 0);
+INSERT INTO tblVersion VALUES (NOW(), 3, 4, 0);
 INSERT INTO tblCategory VALUES (0, '');
