@@ -45,10 +45,18 @@ if ($folder->getAccessMode($user) < M_READWRITE) {
 
 $name    = $_POST["name"];
 $comment = $_POST["comment"];
-$sequence = $_POST["sequence"];
-if (!is_numeric($sequence)) {
+if(isset($_POST["sequence"])) {
+	$sequence = $_POST["sequence"];
+	if (!is_numeric($sequence)) {
+		$sequence = "keep";
+	}
+} else {
 	$sequence = "keep";
 }
+if(isset($_POST["attributes"]))
+	$attributes = $_POST["attributes"];
+else
+	$attributes = array();
 
 $wasupdated = false;
 if(($oldname = $folder->getName()) != $name) {
@@ -102,6 +110,17 @@ if(($oldcomment = $folder->getComment()) != $comment) {
 		UI::exitError(getMLText("folder_title", array("foldername" => $folder->getName())),getMLText("error_occured"));	
 	}
 }
+
+if($attributes) {
+	$oldattributes = $folder->getAttributes();
+	foreach($attributes as $attrdefid=>$attribute) {
+		if(!isset($oldattributes[$attrdefid]) || $attribute != $oldattributes[$attrdefid]->getValue()) {
+			if(!$folder->setAttributeValue($dms->getAttributeDefinition($attrdefid), $attribute))
+				UI::exitError(getMLText("folder_title", array("foldername" => $folder->getName())),getMLText("error_occured"));
+		}
+	}
+}
+
 if(strcasecmp($sequence, "keep")) {
 	if($folder->setSequence($sequence)) {
 	} else {
