@@ -67,7 +67,8 @@ if ($action == "saveSettings")
   $settings->_enableFullSearch = getBoolValue("enableFullSearch");
   $settings->_enableFolderTree = getBoolValue("enableFolderTree");
   $settings->_expandFolderTree = intval($_POST["expandFolderTree"]);
-  $settings->_stopWordsFile = $_POST["stopWordsFile"];
+	$settings->_stopWordsFile = $_POST["stopWordsFile"];
+	$settings->_sortUsersInList = $_POST["sortUsersInList"];
 
   // SETTINGS - SITE - CALENDAR
   $settings->_enableCalendar = getBoolValue("enableCalendar");
@@ -91,6 +92,11 @@ if ($action == "saveSettings")
   $settings->_enableUserImage = getBoolValue("enableUserImage");
   $settings->_disableSelfEdit = getBoolValue("disableSelfEdit");
   $settings->_enablePasswordForgotten = getBoolValue("enablePasswordForgotten");
+  $settings->_passwordStrength = intval($_POST["passwordStrength"]);
+  $settings->_passwordStrengthAlgorithm = strval($_POST["passwordStrengthAlgorithm"]);
+  $settings->_passwordExpiration = intval($_POST["passwordExpiration"]);
+  $settings->_passwordHistory = intval($_POST["passwordHistory"]);
+  $settings->_loginFailure = intval($_POST["loginFailure"]);
   $settings->_encryptionKey = strval($_POST["encryptionKey"]);
 
   // TODO Connectors
@@ -120,6 +126,12 @@ if ($action == "saveSettings")
   // SETTINGS - ADVANCED - EDITION
   $settings->_versioningFileName = $_POST["versioningFileName"];
   $settings->_enableAdminRevApp = getBoolValue("enableAdminRevApp");
+  $settings->_enableVersionDeletion = getBoolValue("enableVersionDeletion");
+  $settings->_enableVersionModification = getBoolValue("enableVersionModification");
+
+  // SETTINGS - ADVANCED - NOTIFICATION
+  $settings->_enableOwnerNotification = getBoolValue("enableOwnerNotification");
+  $settings->_enableNotificationAppRev = getBoolValue("enableNotificationAppRev");
 
   // SETTINGS - ADVANCED - SERVER
   $settings->_coreDir = $_POST["coreDir"];
@@ -129,6 +141,9 @@ if ($action == "saveSettings")
   $settings->_updateNotifyTime = intval($_POST["updateNotifyTime"]);
   $settings->_maxExecutionTime = intval($_POST["maxExecutionTime"]);
 
+  // SETTINGS - ADVANCED - INDEX CMD
+  $settings->_converters = $_POST["converters"];
+
   // -------------------------------------------------------------------------
   // save
   // -------------------------------------------------------------------------
