@@ -96,7 +96,7 @@ if ($user->isAdmin()) {
 		print "<option value=\"".$currUser->getID()."\"";
 		if ($currUser->getID() == $owner->getID())
 			print " selected";
-		print ">" . htmlspecialchars($currUser->getFullname()) . "</option>\n";
+		print ">" . htmlspecialchars($currUser->getLogin() . " - " . $currUser->getFullname()) . "</option>\n";
 	}
 	?>
 	</select>
@@ -240,7 +240,7 @@ foreach ($allUsers as $userObj) {
 	if ($userObj->isGuest()) {
 		continue;
 	}
-	print "<option value=\"".$userObj->getID()."\">" . htmlspecialchars($userObj->getFullName()) . "\n";
+	print "<option value=\"".$userObj->getID()."\">" . htmlspecialchars($userObj->getLogin() . " - " . $userObj->getFullName()) . "</option>\n";
 }
 ?>
 </select>
