@@ -30,7 +30,7 @@ if (!isset($_GET["targetidform3"]) || !is_numeric($_GET["targetidform3"]) || int
 	UI::exitError(getMLText("admin_tools"),getMLText("invalid_folder_id"));
 }
 
-$folderid = $_GET["targetidform3"];
+$folderid = intval($_GET["targetidform3"]);
 $folder = $dms->getFolder($folderid);
 
 if (!is_object($folder)) {
@@ -46,6 +46,7 @@ UI::contentContainerStart();
 
 ?>
 <form action="../op/op.RemoveFolderFiles.php" name="form1" method="POST">
+  <?php echo createHiddenFieldWithKey('removefolderfiles'); ?>
 	<input type="Hidden" name="folderid" value="<?php echo $folderid?>">
 	<p><?php printMLText("confirm_rm_folder_files", array ("foldername" => htmlspecialchars($folder->getName())));?></p>
 	<input type="Submit" value="<?php printMLText("accept");?>">
