@@ -171,6 +171,14 @@ if(!is_writeable($settings->_configFilePath)) {
             <OPTION VALUE="2" <?php if ($settings->_expandFolderTree==2) echo "SELECTED" ?> ><?php printMLText("settings_expandFolderTree_val2");?></OPTION>
           </SELECT>
       </tr>
+      <tr title="<?php printMLText("settings_sortUsersInList_desc");?>">
+        <td><?php printMLText("settings_sortUsersInList");?>:</td>
+        <td>
+          <SELECT name="sortUsersInList">
+            <OPTION VALUE="" <?php if ($settings->_sortUsersInList=='') echo "SELECTED" ?> ><?php printMLText("settings_sortUsersInList_val_login");?></OPTION>
+            <OPTION VALUE="fullname" <?php if ($settings->_sortUsersInList=='fullname') echo "SELECTED" ?> ><?php printMLText("settings_sortUsersInList_val_fullname");?></OPTION>
+          </SELECT>
+      </tr>
 
       <!--
         -- SETTINGS - SITE - CALENDAR
@@ -277,6 +285,31 @@ if(!is_writeable($settings->_configFilePath)) {
         <td><?php printMLText("settings_enablePasswordForgotten");?>:</td>
         <td><input name="enablePasswordForgotten" type="checkbox" <?php if ($settings->_enablePasswordForgotten) echo "checked" ?> /></td>
       </tr>
+      <tr title="<?php printMLText("settings_passwordЅtrength_desc");?>">
+        <td><?php printMLText("settings_passwordStrength");?>:</td>
+        <td><input name="passwordStrength" value="<?php echo $settings->_passwordStrength; ?>" size="2" /></td>
+      </tr>
+      <tr title="<?php printMLText("settings_passwordStrengthAlgorithm_desc");?>">
+        <td><?php printMLText("settings_passwordStrengthAlgorithm");?>:</td>
+        <td>
+				  <select name="passwordStrengthAlgorithm">
+					  <option value="simple" <?php if ($settings->_passwordStrengthAlgorithm=='simple') echo "selected" ?>><?php printMLText("settings_passwordStrengthAlgorithm_valsimple");?></option>
+						<option value="advanced" <?php if ($settings->_passwordStrengthAlgorithm=='advanced') echo "selected" ?>><?php printMLText("settings_passwordStrengthAlgorithm_valadvanced");?></option>
+					</select>
+				</td>
+      </tr>
+      <tr title="<?php printMLText("settings_passwordExpiration_desc");?>">
+        <td><?php printMLText("settings_passwordExpiration");?>:</td>
+        <td><input name="passwordExpiration" value="<?php echo $settings->_passwordExpiration; ?>" size="3" /></td>
+      </tr>
+      <tr title="<?php printMLText("settings_passwordHistory_desc");?>">
+        <td><?php printMLText("settings_passwordHistory");?>:</td>
+        <td><input name="passwordHistory" value="<?php echo $settings->_passwordHistory; ?>" size="2" /></td>
+      </tr>
+      <tr title="<?php printMLText("settings_loginFailure_desc");?>">
+        <td><?php printMLText("settings_loginFailure");?>:</td>
+        <td><input name="loginFailure" value="<?php echo $settings->_loginFailure; ?>" size="2" /></td>
+      </tr>
       <tr title="<?php printMLText("settings_encryptionKey_desc");?>">
         <td><?php printMLText("settings_encryptionKey");?>:</td>
         <td><input name="encryptionKey" value="<?php echo $settings->_encryptionKey; ?>" size="32" /></td>
@@ -379,6 +412,27 @@ if(!is_writeable($settings->_configFilePath)) {
         <td><?php printMLText("settings_enableAdminRevApp");?>:</td>
         <td><input name="enableAdminRevApp" type="checkbox" <?php if ($settings->_enableAdminRevApp) echo "checked" ?> /></td>
       </tr>
+      <tr title="<?php printMLText("settings_enableVersionDeletion_desc");?>">
+        <td><?php printMLText("settings_enableVersionDeletion");?>:</td>
+        <td><input name="enableVersionDeletion" type="checkbox" <?php if ($settings->_enableVersionDeletion) echo "checked" ?> /></td>
+      </tr>
+      <tr title="<?php printMLText("settings_enableVersionModification_desc");?>">
+        <td><?php printMLText("settings_enableVersionModification");?>:</td>
+        <td><input name="enableVersionModification" type="checkbox" <?php if ($settings->_enableVersionModification) echo "checked" ?> /></td>
+      </tr>
+
+      <!--
+        -- SETTINGS - ADVANCED - NOTIFICATION
+      -->
+      <tr ><td><b> <?php printMLText("settings_Notification");?></b></td> </tr>
+      <tr title="<?php printMLText("settings_enableOwnerNotification_desc");?>">
+        <td><?php printMLText("settings_enableOwnerNotification");?>:</td>
+        <td><input name="enableOwnerNotification" type="checkbox" <?php if ($settings->_enableOwnerNotification) echo "checked" ?> /></td>
+      </tr>
+      <tr title="<?php printMLText("settings_enableNotificationAppRev_desc");?>">
+        <td><?php printMLText("settings_enableNotificationAppRev");?>:</td>
+        <td><input name="enableNotificationAppRev" type="checkbox" <?php if ($settings->_enableNotificationAppRev) echo "checked" ?> /></td>
+      </tr>
 
       <!--
         -- SETTINGS - ADVANCED - SERVER
@@ -409,8 +463,17 @@ if(!is_writeable($settings->_configFilePath)) {
         <td><input name="maxExecutionTime" value="<?php echo $settings->_maxExecutionTime ?>" /></td>
       </tr>
 
-
-
+      <tr ><td><b> <?php printMLText("index_converters");?></b></td> </tr>
+<?php
+	foreach($settings->_converters as $mimetype=>$cmd) {
+?>
+      <tr title="<?php echo $mimetype;?>">
+        <td><?php echo $mimetype;?>:</td>
+        <td><input name="converters[<?php echo $mimetype;?>]" value="<?php echo $cmd ?>" size="100" /></td>
+      </tr>
+<?php
+	}
+?>
     </table>
   </div>
 
